import pandas as pd
import plotly.express as px
import plotly.graph_objects as go
import math


fileName = 'Filter_Data.xlsx'           # path to our excel file 
dataFrame = pd.read_excel(fileName)     # read the excel file with pandas

# Filter Values (low-pass)
capacitor = 6.8E-9 # in Farad (6.8nF)
resistor = 745.8 # in Ohm
cutOffFrequency = 1/(2*math.pi*resistor*capacitor)
amplitude = 1 # voltage of signal amplitude
cutOffGain = amplitude / math.sqrt(2)
maxFrequency = dataFrame['Frequency'].max()   ## In pandas you can read a specific column of a data frame by filtering it with ['Column Name']
responseLimit = 2 # in % (user defined)
maxResponse = dataFrame['Filter Response (ideal)'] + dataFrame['Filter Response (ideal)'].max()*responseLimit/100 # Calculate and create max limit channel
minResponse = dataFrame['Filter Response (ideal)'] - dataFrame['Filter Response (ideal)'].max()*responseLimit/100 # Calculate and create min limit channel

fig = px.line(data_frame=dataFrame, x="Frequency", y=["Filter Response (real)","Filter Response (ideal)", "Filter Response (real-fail)"], log_x=True)

fig.add_hline(cutOffGain, line_width=2, line_dash='dash', line_color='green')  
fig.add_vline(cutOffFrequency, line_width=2, line_dash='dash', line_color='green')   

fig.add_trace(go.Scatter(x=[cutOffFrequency], y=[cutOffGain], mode='markers', name='CutOff', marker=dict(size=15, color='red', symbol='x', line=dict(width=2))))
fig.add_vrect(x0=cutOffFrequency, x1=maxFrequency, line_width=0, fillcolor="red", opacity=0.1)

fig.add_scatter(x=dataFrame['Frequency'], y=maxResponse, name='Upper Limit', line_color ='red', line_dash='dot', opacity=0.5)
fig.add_scatter(x=dataFrame['Frequency'], y=minResponse, name='Lower Limit', line_color ='red', line_dash='dot', opacity=0.5)

# Customize the layout
fig.update_layout(
    title_text = "Kreiseder IT Services - Filter Response",
    xaxis_title="Frequency [hz]",
    yaxis_title="Amplitude [volt]",
    legend_title="Legend",
    showlegend=True
)

# Show the chart
fig.show()
